@@ -1,6 +1,6 @@
 use crate::{
     handles::{CData, DataType, HasDataType},
-    InputParameter,
+    parameter::{InputParameter, StableCData},
 };
 use odbc_sys::{CDataType, Date, Numeric, Time, Timestamp};
 use std::{ffi::c_void, ptr::null};
@@ -26,9 +26,9 @@ impl Bit {
 
 /// A plain old data type. With an associated C Type. Must be completely stack allocated without any
 /// external references. In addition to that the buffer size must be known to ODBC in advance.
-/// 
+///
 /// # Safety
-/// 
+///
 /// A type implementing this trait, must be a fixed sized type. The information in the `C_DATA_TYPE`
 /// constant must be enough to determine both the size and the buffer length of an Instance.
 pub unsafe trait Pod: Default + Copy + CData {
@@ -92,6 +92,8 @@ macro_rules! impl_input_fixed_sized {
         }
 
         unsafe impl InputParameter for $t {}
+
+        unsafe impl StableCData for $t {}
     };
 }
 
@@ -106,3 +108,17 @@ impl_input_fixed_sized!(i64, DataType::BigInt);
 
 // Support for fixed size types, which are not unsigned. Time, Date and timestamp types could be
 // supported, implementation DataType would need to take an instance into account.
+
+#[cfg(test)]
+mod test {
+
+    use super::Bit;
+
+    /// `as_bool` should panic if bit is neither 0 or 1.
+    #[test]
+    #[should_panic(expected = "Invalid boolean representation in Bit.")]
+    fn invalid_bit() {
+        let bit = Bit(2);
+        bit.as_bool();
+    }
+}
